from ariadne import ObjectType, InterfaceType


field_error = ObjectType("FieldError")
payload = InterfaceType("Payload")


error_detail = ObjectType("ErrorDetail")
